Tiro Devanagari Hindi has its origins in a typeface designed for the Murty Classical Library of India book series, so is especially suited to traditional literary publishing but also made with the needs of today’s multiple print and screen media in mind. The Tiro Devanagari design applies a contemporary approach to the traditional styling of 19th and 20th Century metal types exemplified in those of the renowned Nirnaya Sagar Press, and is characterised by broader proportions, more generous counters, and strong diagonal strokes and terminals. The Hindi font balances traditional and modern forms of conjuncts. For the Open Font License release, Tiro Devanagari Hindi has been extended to support additional characters, and features a new italic companion. Each font also includes a Latin subset including diacritics for transcription of Indian languages.

Tiro Devanagari Hindi was designed by John Hudson and Fiona Ross. The italic was adapted by Paul Hanslow.

To contribute, see github.com/TiroTypeworks/Indigo.

To learn more, read Modern Tiro Indic collection for classical South Asian texts.